@@ -1,7 +1,7 @@
 from collections import defaultdict
 from itertools import chain
-from time import time
 
+from twisted.internet import reactor
 from twisted.internet.interfaces import IPushProducer
 from twisted.internet.protocol import Factory
 from twisted.internet.task import LoopingCall
@@ -18,6 +18,7 @@ from bravo.packets.beta import make_packet
 from bravo.plugin import retrieve_named_plugins, retrieve_sorted_plugins
 from bravo.protocols.beta import BannedProtocol, BravoProtocol
 from bravo.utilities.chat import chat_name, sanitize_chat
+from bravo.weather import WeatherVane
 from bravo.world import World
 
 (STATE_UNAUTHENTICATED, STATE_CHALLENGED, STATE_AUTHENTICATED,
@@ -40,7 +41,7 @@ class BravoFactory(Factory):
     handshake_hook = None
     login_hook = None
 
-    interface = ""
+    interfaces = []
 
     def __init__(self, name):
         """
@@ -55,15 +56,13 @@ class BravoFactory(Factory):
         self.name = name
         self.config_name = "world %s" % name
 
-        self.port = configuration.getint(self.config_name, "port")
-        self.interface = configuration.getdefault(self.config_name, "host",
-            "")
-
         self.world = World(self.name)
         self.world.factory = self
 
         self.protocols = dict()
 
+        self.vane = WeatherVane(self)
+
     def startFactory(self):
         log.msg("Initializing factory for world '%s'..." % self.name)
 
@@ -85,7 +84,7 @@ class BravoFactory(Factory):
             self.world.enable_cache(cache_level)
 
         log.msg("Starting timekeeping...")
-        self.timestamp = time()
+        self.timestamp = reactor.seconds()
         self.time = self.world.time
         self.update_season()
         self.time_loop = LoopingCall(self.update_time)
@@ -280,17 +279,15 @@ class BravoFactory(Factory):
         once every 5 days. This is a Babylonian in-game year.
         """
 
-        t = time()
+        t = reactor.seconds()
         self.time += 20 * (t - self.timestamp)
         self.timestamp = t
 
-        while self.time > 24000:
-            self.time -= 24000
-
-            self.day += 1
-            while self.day > 360:
-                self.day -= 360
+        days, self.time = divmod(self.time, 24000)
 
+        if days:
+            self.day += days
+            self.day %= 360
             self.update_season()
 
     def broadcast_time(self):
