@@ -189,5 +189,40 @@ class Grass(object):
     before = tuple()
     after = tuple()
 
+class Rain(object):
+    """
+    Make it rain.
+
+    Rain only occurs during spring.
+    """
+
+    implements(IAutomaton)
+
+    blocks = tuple()
+
+    def __init__(self):
+        self.season_loop = LoopingCall(self.check_season)
+
+    def scan(self, chunk):
+        pass
+
+    def feed(self, coords):
+        pass
+
+    def start(self):
+        self.season_loop.start(5 * 60)
+
+    def stop(self):
+        self.season_loop.stop()
+
+    def check_season(self):
+        if factory.world.season.name == "spring":
+            factory.vane.weather = "rainy"
+            reactor.callLater(1 * 60, setattr, factory.vane, "weather",
+                "sunny")
+
+    name = "rain"
+
 trees = Trees()
 grass = Grass()
+rain = Rain()
