@@ -16,7 +16,7 @@ from twisted.web.client import getPage
 from bravo.blocks import blocks, items
 from bravo.config import configuration
 from bravo.entity import Sign
-from bravo.errors import BuildError
+from bravo.errors import BetaClientError, BuildError
 from bravo.factories.infini import InfiniClientFactory
 from bravo.ibravo import (IChatCommand, IPreBuildHook, IPostBuildHook,
     IDigHook, ISignHook, IUseHook)
@@ -26,12 +26,12 @@ from bravo.motd import get_motd
 from bravo.packets.beta import parse_packets, make_packet, make_error_packet
 from bravo.plugin import retrieve_plugins
 from bravo.policy.dig import dig_policies
-from bravo.utilities.coords import split_coords
+from bravo.utilities.coords import adjust_coords_for_face, split_coords
 from bravo.utilities.chat import username_alternatives
 
 (STATE_UNAUTHENTICATED, STATE_CHALLENGED, STATE_AUTHENTICATED) = range(3)
 
-SUPPORTED_PROTOCOL = 13
+SUPPORTED_PROTOCOL = 14
 
 circle = [(i, j)
     for i, j in product(xrange(-10, 10), xrange(-10, 10))
@@ -43,7 +43,7 @@ A list of points in a filled circle of radius 10.
 
 BuildData = namedtuple("BuildData", "block, metadata, x, y, z, face")
 
-class BetaServerProtocol(Protocol):
+class BetaServerProtocol(object, Protocol):
     """
     The Minecraft Alpha/Beta server protocol.
 
@@ -63,6 +63,8 @@ class BetaServerProtocol(Protocol):
     player = None
     username = None
 
+    _health = 20
+
     def __init__(self):
         self.chunks = dict()
         self.windows = dict()
@@ -344,6 +346,23 @@ class BetaServerProtocol(Protocol):
         self.transport.write(make_error_packet(message))
         self.transport.loseConnection()
 
+    # Automatic properties. Assigning to them causes the client to be notified
+    # of changes.
+
+    @property
+    def health(self):
+        return self._health
+
+    @health.setter
+    def health(self, value):
+        if not 0 <= value <= 20:
+            raise BetaClientError("Invalid health value %d" % value)
+
+        if self._health != value:
+            packet = make_packet("health", hp=value)
+            self.transport.write(packet)
+            self._health = value
+
 
 class BannedProtocol(BetaServerProtocol):
     """
@@ -867,18 +886,7 @@ class BravoProtocol(BetaServerProtocol):
                 raise BuildError("Couldn't consume %r from inventory" % block)
 
         # Offset coords according to face.
-        if face == "-x":
-            x -= 1
-        elif face == "+x":
-            x += 1
-        elif face == "-y":
-            y -= 1
-        elif face == "+y":
-            y += 1
-        elif face == "-z":
-            z -= 1
-        elif face == "+z":
-            z += 1
+        x, y, z = adjust_coords_for_face((x, y, z), face)
 
         # Set the block and data.
         dl = [self.factory.world.set_block((x, y, z), block.slot)]
