@@ -2,12 +2,21 @@ from twisted.trial import unittest
 
 from construct import Container
 
+from bravo.errors import BetaClientError
 import bravo.protocols.beta
 
+class FakeTransport(object):
+
+    data = []
+
+    def write(self, data):
+        self.data.append(data)
+
 class TestBetaServerProtocol(unittest.TestCase):
 
     def setUp(self):
         self.p = bravo.protocols.beta.BetaServerProtocol()
+        self.p.transport = FakeTransport()
 
     def test_trivial(self):
         pass
@@ -58,6 +67,43 @@ class TestBetaServerProtocol(unittest.TestCase):
 
         self.assertTrue(error_called[0])
 
+    def test_health_initial(self):
+        """
+        The client's health should start at 20.
+        """
+
+        self.assertEqual(self.p.health, 20)
+
+    def test_health_invalid(self):
+        """
+        An error is raised when an invalid value is assigned for health.
+        """
+
+        self.assertRaises(BetaClientError, setattr, self.p, "health", -1)
+        self.assertRaises(BetaClientError, setattr, self.p, "health", 21)
+
+    def test_health_update(self):
+        """
+        The protocol should emit a health update when its health changes.
+        """
+
+        # Health packet, 19 health
+        expected = "\x08\x00\x13"
+
+        self.p.health = 19
+        self.assertEqual(len(self.p.transport.data), 1)
+        self.assertEqual(self.p.transport.data[0], expected)
+
+    def test_health_no_change(self):
+        """
+        If health is assigned to but not changed, no health update should be
+        issued.
+        """
+
+        self.p.health = 20
+        self.assertFalse(self.p.transport.data)
+
+
 class TestBravoProtocol(unittest.TestCase):
 
     def setUp(self):
