@@ -30,3 +30,29 @@ def taxicab3(x1, y1, z1, x2, y2, z2):
     """
 
     return abs(x1 - x2) + abs(y1 - y2) + abs(z1 - z2)
+
+def adjust_coords_for_face(coords, face):
+    """
+    Adjust a set of coords according to a face.
+
+    The face is a standard string descriptor, such as "+x".
+
+    The "noop" face is supported.
+    """
+
+    x, y, z = coords
+
+    if face == "-x":
+        x -= 1
+    elif face == "+x":
+        x += 1
+    elif face == "-y":
+        y -= 1
+    elif face == "+y":
+        y += 1
+    elif face == "-z":
+        z -= 1
+    elif face == "+z":
+        z += 1
+
+    return x, y, z
